#include <filesystem>
#include <fstream>
#include <iostream>
#include <vector>

#include "qwennlpengine.h"
#include "util.h"
void getmodelinfo() {
    QwenNlpEngine qwenNlpEngine;
    printf("engine name is %s", qwenNlpEngine.engineName().c_str());
    printf("engine current model name is %s",
           qwenNlpEngine.currentModel().c_str());
    printf("engine modelinfo is %s", qwenNlpEngine.modelInfo().c_str());
}

std::string getConfig() {
    return R"(
        {
            "appId" : "",
            "apiKey" : "",
            "secretKey" : ""
        }
    )";
}

void testChatEngine() {
    ai_engine::EngineError error;

    QwenNlpEngine qwenNlpEngine;
    if (qwenNlpEngine.isCloud()) {
        printf("有网络");
    }
    qwenNlpEngine.setConfig(getConfig());
    qwenNlpEngine.setCurrentModel("qwen-plus");
    auto result = qwenNlpEngine.init();
    if (!result.success) {
        std::cout << result.error.getCode() << result.error.getMessage()
                  << std::endl;
    }

    qwenNlpEngine.setTextGenerationResultCallback(
        [](const ai_engine::gen_ai::nlp::TextGenerationResult &result) {
            std::cout << result.modelName << std::endl;
            std::cout << result.text << std::endl;
            std::cout << result.error.getCode() << result.error.getMessage()
                      << std::endl;
        });
    const std::string message = R"(
        {
             "messages": [
                {
                    "role": "system",
                    "content": "你是一个作家，善于用优美的语言写文章"
                },
                {
                    "role": "user",
                    "content": "今天天气不错"
                }
            ]
        }
    )";
    result = qwenNlpEngine.chat(message);
    if (!result.success) {
        std::cout << result.error.getCode() << result.error.getMessage()
                  << std::endl;
    }
    const std::string message1 = R"(
        {
             "messages": [
                {
                    "role": "user",
                    "content": "我刚才问的什么"
                }
            ]
        }
    )";
    while (std::getchar() != '\n') {
    }
    qwenNlpEngine.chat(message1);

    while (std::getchar() != '\n') {
        qwenNlpEngine.stopChat();
        qwenNlpEngine.destroy();
    }
}

void testGenerateContentEngine() {
    ai_engine::EngineError error;

    QwenNlpEngine qwenNlpEngine;
    if (qwenNlpEngine.isCloud()) {
        printf("有网络");
    }
    qwenNlpEngine.setConfig(getConfig());
    qwenNlpEngine.init();

    qwenNlpEngine.setTextGenerationResultCallback(
        [](const ai_engine::gen_ai::nlp::TextGenerationResult &result) {
            std::cout << result.modelName << std::endl;
            std::cout << result.text << std::endl;
            std::cout << result.error.getCode() << result.error.getMessage()
                      << std::endl;
        });
    const std::string message = R"(
        {
             "prompt": "你是谁"
    )";
    qwenNlpEngine.generateContent(message);

    while (std::getchar() != '\n') {
        qwenNlpEngine.stopGenerateContent();
        qwenNlpEngine.destroy();
    }
}

int main() {
    getmodelinfo();
    testChatEngine();
    testGenerateContentEngine();
    return 0;
}